@@ -6,15 +6,20 @@ package File::Flat;
 # This should work on non-Unix platforms, but there may be some
 # minor remaining bugs.
 
+use 5.005;
 use strict;
-use UNIVERSAL 'isa';
-use Cwd         ();
-use File::Spec  ();
-use IO::File    ();
+use Cwd        ();
+use File::Spec ();
+use IO::File   ();
+use prefork    'File::Slurp';
+use prefork    'File::Temp';
+use prefork    'File::Copy';
+use prefork    'File::Copy::Recursive';
+use prefork    'File::Remove';
 
 use vars qw{$VERSION $errstr %modes $AUTO_PRUNE};
 BEGIN {
-	$VERSION = '0.94';
+	$VERSION = '1.01';
 
 	# The main error string
 	$errstr  = '';
@@ -49,7 +54,7 @@ sub isaFile { defined $_[1] and -f $_[1] }
 sub isaDirectory { defined $_[1] and -d $_[1] }
 
 # Do we have permission to read a filesystem object.
-sub canRead { defined $_[1] and -e $_[1] and -r $_[1] }
+sub canRead { defined $_[1] and -e $_[1] and -r _ }
 
 # Do we have permission to write to a filesystem object.
 # If it doesn't exist, can we create it.
@@ -63,13 +68,13 @@ sub canWrite {
 }
 
 # Can we both read and write to a filesystem object
-sub canReadWrite { defined $_[1] and -r $_[1] and -w $_[1] }
+sub canReadWrite { defined $_[1] and -r $_[1] and -w _ }
 
 # Do we have permission to execute a filesystem object
 sub canExecute { defined $_[1] and -x $_[1] }
 
 # Could we open this as a file
-sub canOpen { defined $_[1] and -f $_[1] and -r $_[1] }
+sub canOpen { defined $_[1] and -f $_[1] and -r _ }
 
 # Could a file or directory be removed, were we to try
 sub canRemove {
@@ -216,7 +221,7 @@ sub write {
 	# This also makes sure the stuff we are going to write is ok.
 	my $contents;
 	if ( ref $_[0] ) {
-		unless ( isa( $_[0], 'SCALAR' ) or isa( $_[0], 'ARRAY' ) ) {
+		unless ( UNIVERSAL::isa($_[0], 'SCALAR') or UNIVERSAL::isa($_[0], 'ARRAY') ) {
 			return $class->_error( "Unknown or invalid argument to ->write" );
 		}
 
@@ -239,7 +244,7 @@ sub write {
 	}
 
 	# Write the contents to the handle
-	if ( isa( $contents, 'SCALAR' ) ) {
+	if ( UNIVERSAL::isa($contents, 'SCALAR') ) {
 		$file->print( $$contents ) or return undef;
 	} else {
 		foreach ( @$contents ) {
@@ -362,9 +367,9 @@ sub copy {
 			"Failed to create directory '$target'" );
 	}
 
-	# Hand off to File::NCopy
-	require File::NCopy;
-	my $rv = File::NCopy::copy( \1, $tocopy, $target );
+	# Hand off to File::Copy::Recursive
+	require File::Copy::Recursive;
+	my $rv = File::Copy::Recursive::dircopy( $tocopy, $target );
 	defined $rv ? $rv : $class->_andRemove( $remove_on_fail );
 }
 
@@ -507,7 +512,6 @@ package File::Flat::Object;
 # The methods are the same as for File::Flat, where applicable.
 
 use strict;
-use UNIVERSAL 'isa';
 use File::Spec ();
 
 sub new {
@@ -548,11 +552,11 @@ sub _init {
 sub exists       { -e $_[0]->{original} }
 sub isaFile      { -f $_[0]->{original} }
 sub isaDirectory { -d $_[0]->{original} }
-sub canRead      { -e $_[0]->{original} and -r $_[0]->{original} }
-sub canWrite     { -e $_[0]->{original} and -w $_[0]->{original} }
-sub canReadWrite { -e $_[0]->{original} and -r $_[0]->{original} and -w $_[0]->{original} }
-sub canExecute   { -e $_[0]->{original} and -x $_[0]->{original} }
-sub canOpen      { -f $_[0]->{original} and -r $_[0]->{original} }
+sub canRead      { -e $_[0]->{original} and -r _ }
+sub canWrite     { -e $_[0]->{original} and -w _ }
+sub canReadWrite { -e $_[0]->{original} and -r _ and -w _ }
+sub canExecute   { -e $_[0]->{original} and -x _ }
+sub canOpen      { -f $_[0]->{original} and -r _ }
 sub fileSize     { File::Flat->fileSize( $_[0]->{original} ) }
 
 # Can we create this file/directory, if it doesn't exist.
@@ -606,10 +610,10 @@ sub _canCreate {
 sub canRemove { die "The ->canRemove method has not been implemented yet" }
 
 # Is the file a text file.
-sub isText { -e $_[0]->{original} and -f $_[0]->{original} and -T $_[0]->{original} }
+sub isText { -e $_[0]->{original} and -f _ and -T $_[0]->{original} }
 
 # Is a file a binary file.
-sub isBinary { -e $_[0]->{original} and -f $_[0]->{original} and -B $_[0]->{original} }
+sub isBinary { -e $_[0]->{original} and -f _ and -B $_[0]->{original} }
 
 
 
@@ -701,13 +705,14 @@ sub prune {
 		# Does it contain anything, other that (possibly) curdir and updir entries
 		opendir( PRUNEDIR, $dir )
 			or return $self->_error("opendir failed while pruning: $!");
-		foreach ( readdir PRUNEDIR ) {
+		my @files = readdir PRUNEDIR;
+		closedir PRUNEDIR;
+		foreach ( @files ) {
 			next if $_ eq File::Spec->curdir;
 			next if $_ eq File::Spec->updir;
 
 			# Found something, we don't need to prune this,
 			# or anything else for that matter.
-			closedir PRUNEDIR;
 			return 1;
 		}
 
@@ -844,8 +849,8 @@ All methods are statically called, for example, to write some stuff to a file.
 =head2 Use of other modules
 
 File::Flat tries to use more task orientated modules wherever possible. This
-includes the use of File::Copy, File::NCopy, File::Remove and others. These
-are mostly loaded on-demand.
+includes the use of L<File::Copy>, L<File::Copy::Recursive>, L<File::Remove>
+and others. These are mostly loaded on-demand.
 
 =head2 Pruning and $AUTO_PRUNE
 
@@ -880,13 +885,8 @@ this locally, such as in the following example.
 
 =head2 Non-Unix platforms
 
-File::Flat itself should be completely capable of handling any platform
-through its exclusive use of File::Spec.
-
-However, some of the modules it relies upon, particularly File::Remove, and
-possible File::NCopy are not File::Spec happy yet. Results may wary on non
-Unix platforms. Users of non-Unix platforms are invited to patch
-File::Remove ( and possibly File::NCopy ) and File::Flat should work.
+As of version 0.97 File::Flat should work correctly on Win32. Other
+platforms (such as VMS) are believed to work, but require confirmation.
 
 =head1 METHODS
 
@@ -1104,8 +1104,7 @@ Returns true on success, returns undef on error.
 =head1 TO DO
 
 Function interface to be written, like
-L<File::Spec::Functions|File::Spec::Functions>, to provide importable
-functions.
+L<File::Spec::Functions>, to provide importable functions.
 
 There's something bigger here too, I'm not exactly sure what it is,
 but I think there might be the beginings of a unified filesystem
@@ -1115,21 +1114,21 @@ interface here... FSI.pm
 
 Bugs should be filed at via the CPAN bug tracker at:
 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File%3A%3AFlat>
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File-Flat>
 
 For other issues or comments, contact the author
 
 =head1 AUTHORS
 
-Adam Kennedy (Maintainer), L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<File::Spec|File::Spec>
+L<File::Spec>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002 - 2004 Adam Kennedy. All rights reserved.
+Copyright (c) 2002 - 2006 Adam Kennedy.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
